--- a/Sources/Lite/nanoxml/XMLElement.java.orig	2016-03-04 09:16:52.339000000 +0000
+++ a/Sources/Lite/nanoxml/XMLElement.java	2016-03-04 09:19:03.213000000 +0000
@@ -63,8 +63,8 @@
  * The following example shows how to list the attributes of an element:
  * <UL><CODE>
  * XMLElement element = ...;<BR>
  * Enumeration enum = element.getAttributeNames();<BR>
  * while (enum.hasMoreElements()) {<BR>
  * &nbsp;&nbsp;&nbsp;&nbsp;String key = (String) enum.nextElement();<BR>
  * &nbsp;&nbsp;&nbsp;&nbsp;String value = element.getStringAttribute(key);<BR>
  * &nbsp;&nbsp;&nbsp;&nbsp;System.out.println(key + " = " + value);<BR>
@@ -478,9 +478,9 @@
         this.children = new Vector();
         this.entities = entities;
         this.lineNr = 0;
-        Enumeration enum = this.entities.keys();
-        while (enum.hasMoreElements()) {
-            Object key = enum.nextElement();
+        Enumeration myEnum = this.entities.keys();
+        while (myEnum.hasMoreElements()) {
+            Object key = myEnum.nextElement();
             Object value = this.entities.get(key);
             if (value instanceof String) {
                 value = ((String) value).toCharArray();
@@ -2168,10 +2168,10 @@
         writer.write('<');
         writer.write(this.name);
         if (! this.attributes.isEmpty()) {
-            Enumeration enum = this.attributes.keys();
-            while (enum.hasMoreElements()) {
+            Enumeration myEnum = this.attributes.keys();
+            while (myEnum.hasMoreElements()) {
                 writer.write(' ');
-                String key = (String) enum.nextElement();
+                String key = (String) myEnum.nextElement();
                 String value = (String) this.attributes.get(key);
                 writer.write(key);
                 writer.write('='); writer.write('"');
@@ -2189,9 +2189,9 @@
             writer.write('/'); writer.write('>');
         } else {
             writer.write('>');
-            Enumeration enum = this.enumerateChildren();
-            while (enum.hasMoreElements()) {
-                XMLElement child = (XMLElement) enum.nextElement();
+            Enumeration myEnum = this.enumerateChildren();
+            while (myEnum.hasMoreElements()) {
+                XMLElement child = (XMLElement) myEnum.nextElement();
                 child.write(writer);
             }
             writer.write('<'); writer.write('/');
@@ -63,8 +63,8 @@
  * <UL><CODE>
  * XMLElement element = ...;<BR>
- * Enumeration enum = element.getAttributeNames();<BR>
- * while (enum.hasMoreElements()) {<BR>
+ * Enumeration myEnum = element.getAttributeNames();<BR>
+ * while (myEnum.hasMoreElements()) {<BR>
  * &nbsp;&nbsp;&nbsp;&nbsp;String key = (String) enum.nextElement();<BR>
  * &nbsp;&nbsp;&nbsp;&nbsp;String value = element.getStringAttribute(key);<BR>
